==> haskell-data-default-instances-base-0.1.0.3-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default-instances-base
version:              0.1.0.3
visibility:           public
id:                   data-default-instances-base-0.1.0.3-FQ6tvaQBNaFEEQjRz7FYKp
key:                  data-default-instances-base-0.1.0.3-FQ6tvaQBNaFEEQjRz7FYKp
license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             Default instances for types in base
description:
    This module reëxports the '\''Data.Default.Class.Default'\'' instances from the
    "Data.Default.Class" module.

category:             Data
abi:                  ccc39d6b304734aa7e6f82d23fc14f13
exposed:              True
exposed-modules:      Data.Default.Instances.Base
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-base-0.1.0.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-base-0.1.0.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-base-0.1.0.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default-instances-base
hs-libraries:
    HSdata-default-instances-base-0.1.0.3-FQ6tvaQBNaFEEQjRz7FYKp

depends:
    base-4.17.2.1 data-default-class-0.1.2.1-J2UCuIureY5CbnU1SgrtGb

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-base/html/data-default-instances-base.haddock

haddock-html:         /usr/share/doc/haskell-data-default-instances-base/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-default-instances-base-0.1.0.3-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default-instances-base
version:              0.1.0.3
visibility:           public
id:                   data-default-instances-base-0.1.0.3-7I3hARRnbuGKpYi6jyzl4J
key:                  data-default-instances-base-0.1.0.3-7I3hARRnbuGKpYi6jyzl4J
license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             Default instances for types in base
description:
    This module reëxports the '\''Data.Default.Class.Default'\'' instances from the
    "Data.Default.Class" module.

category:             Data
abi:                  b5f0b5c87d9ff14b346f35b1bd8e1c32
exposed:              True
exposed-modules:      Data.Default.Instances.Base
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-base-0.1.0.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-base-0.1.0.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-base-0.1.0.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default-instances-base
hs-libraries:
    HSdata-default-instances-base-0.1.0.3-7I3hARRnbuGKpYi6jyzl4J

depends:
    base-4.17.2.1 data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-base/html/data-default-instances-base.haddock

haddock-html:         /usr/share/doc/haskell-data-default-instances-base/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
